@@ -80,10 +80,10 @@ LOG = utils.make_a_logger()
 # is irrelevant. Otherwise all must match for skip to happen.
 UNBUILDABLE_IMAGES = {
     'aarch64': {
-        "bifrost-base",      # someone need to get upstream working first
+        "bifrost-base",        # someone need to get upstream working first
         "prometheus-msteams",  # no aarch64 binary
-        "prometheus-mtail",  # no aarch64 binary
-        "skydive-base",      # no aarch64 binary
+        "prometheus-mtail",    # no aarch64 binary
+        "skydive-base",        # no aarch64 binary
     },
 
     'binary': {
@@ -91,6 +91,7 @@ UNBUILDABLE_IMAGES = {
         "blazar-base",
         "cyborg-base",
         "freezer-base",
+        "gnocchi-base",  # https://github.com/gnocchixyz/gnocchi/issues/1304
         "kuryr-base",
         "monasca-base",
         "monasca-thresh",
@@ -99,6 +100,7 @@ UNBUILDABLE_IMAGES = {
     },
 
     'source': {
+        "gnocchi-base",  # https://github.com/gnocchixyz/gnocchi/issues/1304
     },
 
     'centos': {
@@ -108,10 +110,43 @@ UNBUILDABLE_IMAGES = {
         "tgtd",                  # Not supported on CentOS 8
     },
 
+    # Issues for SHA1 keys:
+    # https://github.com/elastic/elasticsearch/issues/85876
+    # https://github.com/grafana/grafana/issues/41036
+    'centos9': {
+        "elasticsearch",         # SHA1 gpg key
+        "elasticsearch-curator",
+        "hacluster-pcs",         # Missing crmsh package
+        "kibana",                # SHA1 gpg key
+        "logstash",              # SHA1 gpg key
+        "kafka",                 # Monasca dependency
+        "monasca-base",          # No support for OpenSearch
+        "nova-spicehtml5proxy",  # Missing spicehtml5 package
+        "ovsdpdk",               # Not supported on CentOS
+        "proxysql",              # 2.3 not supported on EL9
+        "storm-base",            # Monasca dependency
+        "tgtd",                  # Not supported on CentOS
+    },
+
     'debian': {
         "qdrouterd",     # no qdrouterd package in Debian bullseye
     },
 
+    'rocky': {
+        "elasticsearch",         # SHA1 gpg key
+        "elasticsearch-curator",
+        "hacluster-pcs",         # Missing crmsh package
+        "kibana",                # SHA1 gpg key
+        "logstash",              # SHA1 gpg key
+        "kafka",                 # Monasca dependency
+        "monasca-base",          # No support for OpenSearch
+        "nova-spicehtml5proxy",  # Missing spicehtml5 package
+        "ovsdpdk",               # Not supported on CentOS
+        "proxysql",              # 2.3 not supported on EL9
+        "storm-base",            # Monasca dependency
+        "tgtd",                  # Not supported on CentOS
+    },
+
     'ubuntu': {
         "qdrouterd",  # There is no qdrouterd package for Ubuntu
     },
@@ -469,6 +504,14 @@ class BuildTask(DockerTask):
 
     def builder(self, image):
 
+        def _test_malicious_tarball(archive, path):
+            tar_file = tarfile.open(archive, 'r|*')
+            for n in tar_file.getnames():
+                if not os.path.abspath(os.path.join(path, n)).startswith(path):
+                    tar_file.close()
+                    self.logger.error(f'Unsafe filenames in archive {archive}')
+                    raise ArchivingError
+
         def make_an_archive(items, arcname, item_child_path=None):
             if not item_child_path:
                 item_child_path = arcname
@@ -482,8 +525,9 @@ class BuildTask(DockerTask):
                     archives.append(archive_path)
             if archives:
                 for archive in archives:
+                    _test_malicious_tarball(archive, items_path)
                     with tarfile.open(archive, 'r') as archive_tar:
-                        archive_tar.extractall(path=items_path)
+                        archive_tar.extractall(path=items_path)  # nosec
             else:
                 try:
                     os.mkdir(items_path)
@@ -688,7 +732,15 @@ class KollaWorker(object):
         self.rpm_setup = self.build_rpm_setup(rpm_setup_config)
 
         if self.base in ['centos']:
-            self.conf.distro_python_version = "3.6"
+            if self.base_tag.startswith('stream9'):
+                self.conf.distro_python_version = "3.9"
+            else:
+                self.conf.distro_python_version = "3.6"
+
+            self.distro_package_manager = 'dnf'
+            self.base_package_type = 'rpm'
+        elif self.base in ['rocky']:
+            self.conf.distro_python_version = "3.9"
             self.distro_package_manager = 'dnf'
             self.base_package_type = 'rpm'
         elif self.base in ['debian']:
@@ -717,6 +769,11 @@ class KollaWorker(object):
                      "due to lack of packages for other architectures.")
             sys.exit(1)
 
+        if (self.install_type == 'binary' and
+                self.base_tag.startswith('stream9')):
+            LOG.info("CentOS Stream 9 is available only for source images.")
+            sys.exit(1)
+
         if self.install_type == 'binary':
             LOG.info("Building binary images is now deprecated. Consider "
                      "switching to source ones.")
@@ -894,8 +951,8 @@ class KollaWorker(object):
 
     def create_dockerfiles(self):
         kolla_version = version.version_info.cached_version_string()
-        supported_distro_name = common_config.DISTRO_PRETTY_NAME.get(
-            self.base)
+        supported_distro_name = common_config.DISTRO_PRETTY_NAME.get(self.base)
+
         for path in self.docker_build_paths:
             template_name = "Dockerfile.j2"
             image_name = path.split("/")[-1]
@@ -1015,6 +1072,8 @@ class KollaWorker(object):
 
         # mark unbuildable images and their children
         base = self.base
+        if base == 'centos' and self.base_tag == 'stream9':
+            base = 'centos9'
 
         tag_element = r'(%s|%s|%s)' % (base,
                                        self.install_type,
